Page 171 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 171

Home

    Harvard Law School for two and a half years.

    Much of the wisdom and insight of this gifted
    individual resulted from his determined pursuit of
    knowledge. His book The Romance Of Education dealt
    with such diverse fields as language, history,

    with

    diverse

    fields

    with such diverse fields as language, history,
    mathematics, and poetry, all subjects in which he had
    excelled. His personal library grew to contain 5,000
    volumes, most of which he had read. After rising to
    national prominence as a successful businessman, he laid
    aside his business responsibilities to devote his life to
    bringing the truth to the American people.

    And so it was that on December 9, 1958, Robert

    as

    Welch met with 11 other prominent men in a two day
    meeting which resulted in the founding of The John Birch
    Society. This meeting that took place in Indianapolis,
    Indiana, began a new movement in history. Outside of
    religious groups, this was the first time a major
    organization was ever created for the sole purpose of
    using truth as a weapon against evil. The motto of The
    John Birch Society (JBS) was expressed in this manner
    by its founder: "Education is our total strategy and truth
    is our only weapon."!

    As a result of the founding of the JBS, the
    manipulators of public opinion faced something they had
    never faced before. It soon became evident to them that

    As

    the

    the JBS understood exactly what they were up to, and
    knew how to use the one weapon they could not stand
    against. That weapon was simply truth.

    166

    The Secret Side of History

    fourth in a class of almost a thousand. He then entered